aboutsummaryrefslogtreecommitdiffstats
path: root/lib/CodeGen/SelectionDAG/ScheduleDAGFast.cpp
diff options
context:
space:
mode:
authorDan Gohman <gohman@apple.com>2008-12-23 18:36:58 +0000
committerDan Gohman <gohman@apple.com>2008-12-23 18:36:58 +0000
commitc9a5b9e38b442c2ae6b115213a07df3fcd14708d (patch)
tree13a3c0ce02152eae878387b3afa36cebd8aadda7 /lib/CodeGen/SelectionDAG/ScheduleDAGFast.cpp
parent1bda0541f0ca613179052a203a62c2d36d9c5a46 (diff)
downloadexternal_llvm-c9a5b9e38b442c2ae6b115213a07df3fcd14708d.zip
external_llvm-c9a5b9e38b442c2ae6b115213a07df3fcd14708d.tar.gz
external_llvm-c9a5b9e38b442c2ae6b115213a07df3fcd14708d.tar.bz2
Rename BuildSchedUnits to BuildSchedGraph, and refactor the
code in ScheduleDAGSDNodes' BuildSchedGraph into separate functions. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@61376 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/CodeGen/SelectionDAG/ScheduleDAGFast.cpp')
-rw-r--r--lib/CodeGen/SelectionDAG/ScheduleDAGFast.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/CodeGen/SelectionDAG/ScheduleDAGFast.cpp b/lib/CodeGen/SelectionDAG/ScheduleDAGFast.cpp
index d917386..113dfb1 100644
--- a/lib/CodeGen/SelectionDAG/ScheduleDAGFast.cpp
+++ b/lib/CodeGen/SelectionDAG/ScheduleDAGFast.cpp
@@ -114,8 +114,8 @@ void ScheduleDAGFast::Schedule() {
LiveRegDefs.resize(TRI->getNumRegs(), NULL);
LiveRegCycles.resize(TRI->getNumRegs(), 0);
- // Build scheduling units.
- BuildSchedUnits();
+ // Build the scheduling graph.
+ BuildSchedGraph();
DEBUG(for (unsigned su = 0, e = SUnits.size(); su != e; ++su)
SUnits[su].dumpAll(this));